package ca.canadapost.cpcdp.platforms;

import ca.canadapost.cpcdp.platforms.stub.*;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.frontend.ClientProxy;
import ca.canadapost.cpcdp.platforms.util.ClientUtil;

import javax.xml.ws.BindingProvider;
import javax.xml.ws.soap.SOAPFaultException;
import java.util.Map;

/**
 * Sample code for the GetMerchantRegistrationInfo Canada Post service.
 * <p>
 * The GetMerchantRegistrationInfo service is called by the ecommerce platform after
 * the merchant has completed the Canada Post sign-up process. This call returns
 * merchant data such as customer number and merchant username and password. This
 * information is necessary for the platform to perform web service shipping
 * transactions for the merchant.
 * <p>
 * This sample is configured to access the Developer Program sandbox environment.
 * Use your development key username and password for the web service credentials.
 */
public class GetMerchantRegistrationInfoClient {
    // Main class for local testing only
    public static void main(String[] args) {
        try {
			// Your username, password and customer number are imported from the following file: CPCWS_SOAP_Platforms_Java_Samples/user.properties
            Map<String, String> userProperties = ClientUtil.getUserProperties("user.properties");
            String username = userProperties.get("username");
            String password = userProperties.get("password");

            MerchantRegistrationService service = new MerchantRegistrationService();
            MerchantRegistrationPortType port = service.getMerchantRegistrationPort();

            //set endpoint
            Map ctx = ((BindingProvider) port).getRequestContext();
            ctx.put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, "https://ct.soa-gw.canadapost.ca/ot/soap/merchant/registration");

            //wss4j interceptor -  add UsernameToken to soap header
            Client client = ClientProxy.getClient(port);
            client.getOutInterceptors().add(ClientUtil.getUsernameTokenInterceptor(username, password));

            //build request
            GetMerchantRegistrationInfoRequest request = new GetMerchantRegistrationInfoRequest();
            request.setLocale("FR");
            request.setTokenId("1111111111111111111111");

            //execute request
            GetMerchantRegistrationInfoResponse response = port.getMerchantRegistrationInfo(request);

            //retrieve values from response
            if(response.getMessages() == null){
                if(response.getMerchantInfo() != null) {
                    if (response.getMerchantInfo().getCustomerNumber() != null) {
                        System.out.println("Customer Number: " + response.getMerchantInfo().getCustomerNumber());
                    }
                    if (response.getMerchantInfo().getContractNumber() != null) {
                        System.out.println("Contract Number: " + response.getMerchantInfo().getContractNumber());
                    }
                    if (response.getMerchantInfo().getMerchantUsername() != null) {
                        System.out.println("Merchant Username: " + response.getMerchantInfo().getMerchantUsername());
                    }
                    if (response.getMerchantInfo().getMerchantPassword() != null) {
                        System.out.println("Merchant Password: " + response.getMerchantInfo().getMerchantPassword());
                    }
                    System.out.println("Has Default CC: " + response.getMerchantInfo().isHasDefaultCreditCard());
                }
            } else {
                for(MessagesType.Message m : response.getMessages().getMessage()){
                    System.out.println("Error Code: " + m.getCode());
                    System.out.println("Error Message: " + m.getDescription());
                }
            }
        }
        catch (SOAPFaultException e) {
            System.out.println("Fault Code: " + e.getFault().getFaultCode());
            System.out.println("Fault Reason: " + e.getFault().getFaultString());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
